@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.18";
+our $VERSION = "2.19";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -12,6 +12,7 @@ use Carp;
 use List::Util qw(pairmap pairgrep);
 use Scalar::Util qw(looks_like_number);
 use Text::VisualWidth::PP 'vwidth';
+sub pwidth { vwidth $_[0] =~ s/\X\cH{1,2}//gr }
 
 ######################################################################
 use Exporter 'import';
@@ -407,9 +408,12 @@ sub fold {
     ##
     if ($_ ne '' and $opt->do_runout) {
 	if ($folded =~ m{ (?<color>  (?! ${reset_re}) ${color_re}*+ )
-			  (?<runout> $prohibition_re{end}+ ) \z }xp
+			  (?<runout>
+			    (?: ($prohibition_re{end}) (?: \cH{1,2} \g{-1})* )+
+			  ) \z
+			}xp
 	    and ${^PREMATCH} ne ''
-	    and (my $w = vwidth $+{runout}) <= $opt->{runout}) {
+	    and (my $w = pwidth $+{runout}) <= $opt->{runout}) {
 
 	    $folded = ${^PREMATCH};
 	    $_ = join '', ${^MATCH}, @reset, $_;
@@ -430,7 +434,8 @@ sub fold {
 	my $m = $opt->{runin};
 	while ($m > 0 and
 	       m{\A (?<color> ${color_re}*+)
-	            (?<runin> $prohibition_re{head})
+	            (?<runin> $prohibition_re{head} )
+		    ( \cH{1,2} \g{runin} )* # multiple strike
 	            (?<reset> (?: $erase_re* $reset_re+ $erase_re* )? )
 	       }xp) {
 	    my $w = vwidth $+{runin};
@@ -554,7 +559,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.18
+Version 2.19
 
 =head1 SYNOPSIS
 
@@ -583,11 +588,12 @@ Version 2.18
 
 =head1 DESCRIPTION
 
-Text::ANSI::Fold provides capability to fold a text into two strings
-by given width.  Text can include ANSI terminal sequences.  If the
-text is divided in the middle of ANSI-effect region, reset sequence is
-appended to folded text, and recover sequence is prepended to trimmed
-string.
+L<Text::ANSI::Fold> provides capability to divide a text into two
+parts by given width.  Text can include ANSI terminal sequences and
+the width is calculated by its visible representation.  If the text is
+divided in the middle of colored region, reset sequence is appended to
+the former text, and color recover sequence is inserted before the
+latter string.
 
 This module also support Unicode Asian full-width and non-spacing
 combining characters properly.  Japanese text formatting with
@@ -596,7 +602,7 @@ the linebreak mode to enable it.
 
 Since the overhead of ANSI escape sequence handling is not significant
 when the data does not include them, this module can be used for
-normal text processing with little penalty.
+normal text processing with small penalty.
 
 Use exported B<ansi_fold> function to fold original text, with number
 of visual columns you want to cut off the text.
@@ -606,9 +612,9 @@ of visual columns you want to cut off the text.
 It returns a pair of strings; first one is folded text, and second is
 the rest.
 
-Additional third result is the visual width of the folded text.  It is
-not always same as given width, and you may want to know how many
-columns returned string takes for further processing.
+Additional third result is visual width of the folded text.  It is not
+always same as given width, and you may want to know how many columns
+returned string takes for further processing.
 
 Negative width value is taken as unlimited.  So the string is never
 folded, but you can use this to expand tabs and to get visual string
@@ -899,7 +905,7 @@ Collection of ANSI related tools.
 
 =item L<Text::ANSI::Fold>
 
-=item L<https://github.com/kaz-utashiro/Text-ANSI-Fold>
+=item L<https://github.com/tecolicom/Text-ANSI-Fold>
 
 Distribution and repository.
 
